@@ -22,52 +22,64 @@ package org.apache.cxf.systest.jaxrs;
 import java.io.IOException;
 import java.io.InputStream;
 import java.lang.annotation.Annotation;
+import java.lang.management.ManagementFactory;
+import java.lang.management.ThreadMXBean;
 import java.lang.reflect.Type;
 import java.net.URI;
 import java.net.URLEncoder;
 import java.net.UnknownHostException;
+import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Collection;
 import java.util.Collections;
 import java.util.List;
+import java.util.Map;
+import java.util.Objects;
 import java.util.concurrent.ExecutionException;
+import java.util.concurrent.ExecutorService;
+import java.util.concurrent.Executors;
 import java.util.concurrent.Future;
+import java.util.concurrent.TimeUnit;
+import java.util.concurrent.atomic.AtomicLong;
+import java.util.concurrent.locks.LockSupport;
+import java.util.function.Supplier;
 
-import javax.annotation.Priority;
-import javax.ws.rs.WebApplicationException;
-import javax.ws.rs.client.Client;
-import javax.ws.rs.client.ClientBuilder;
-import javax.ws.rs.client.ClientRequestContext;
-import javax.ws.rs.client.ClientRequestFilter;
-import javax.ws.rs.client.ClientResponseContext;
-import javax.ws.rs.client.ClientResponseFilter;
-import javax.ws.rs.client.Entity;
-import javax.ws.rs.client.Invocation;
-import javax.ws.rs.client.InvocationCallback;
-import javax.ws.rs.client.ResponseProcessingException;
-import javax.ws.rs.client.WebTarget;
-import javax.ws.rs.container.ResourceContext;
-import javax.ws.rs.core.Context;
-import javax.ws.rs.core.Feature;
-import javax.ws.rs.core.FeatureContext;
-import javax.ws.rs.core.GenericEntity;
-import javax.ws.rs.core.GenericType;
-import javax.ws.rs.core.HttpHeaders;
-import javax.ws.rs.core.MediaType;
-import javax.ws.rs.core.MultivaluedMap;
-import javax.ws.rs.core.Response;
-import javax.ws.rs.ext.MessageBodyReader;
-import javax.ws.rs.ext.ParamConverter;
-import javax.ws.rs.ext.ParamConverterProvider;
-import javax.ws.rs.ext.ReaderInterceptor;
-import javax.ws.rs.ext.ReaderInterceptorContext;
-import javax.ws.rs.ext.WriterInterceptor;
-import javax.ws.rs.ext.WriterInterceptorContext;
-import javax.xml.bind.JAXBElement;
 import javax.xml.namespace.QName;
-import javax.xml.ws.Holder;
 
-import com.fasterxml.jackson.jaxrs.json.JacksonJaxbJsonProvider;
+import com.fasterxml.jackson.jakarta.rs.json.JacksonXmlBindJsonProvider;
 
+import jakarta.annotation.Priority;
+import jakarta.ws.rs.WebApplicationException;
+import jakarta.ws.rs.client.Client;
+import jakarta.ws.rs.client.ClientBuilder;
+import jakarta.ws.rs.client.ClientRequestContext;
+import jakarta.ws.rs.client.ClientRequestFilter;
+import jakarta.ws.rs.client.ClientResponseContext;
+import jakarta.ws.rs.client.ClientResponseFilter;
+import jakarta.ws.rs.client.Entity;
+import jakarta.ws.rs.client.Invocation;
+import jakarta.ws.rs.client.InvocationCallback;
+import jakarta.ws.rs.client.ResponseProcessingException;
+import jakarta.ws.rs.client.WebTarget;
+import jakarta.ws.rs.container.ResourceContext;
+import jakarta.ws.rs.core.Context;
+import jakarta.ws.rs.core.Feature;
+import jakarta.ws.rs.core.FeatureContext;
+import jakarta.ws.rs.core.GenericEntity;
+import jakarta.ws.rs.core.GenericType;
+import jakarta.ws.rs.core.HttpHeaders;
+import jakarta.ws.rs.core.MediaType;
+import jakarta.ws.rs.core.MultivaluedMap;
+import jakarta.ws.rs.core.Response;
+import jakarta.ws.rs.ext.MessageBodyReader;
+import jakarta.ws.rs.ext.ParamConverter;
+import jakarta.ws.rs.ext.ParamConverterProvider;
+import jakarta.ws.rs.ext.ReaderInterceptor;
+import jakarta.ws.rs.ext.ReaderInterceptorContext;
+import jakarta.ws.rs.ext.WriterInterceptor;
+import jakarta.ws.rs.ext.WriterInterceptorContext;
+import jakarta.xml.bind.JAXBElement;
+import jakarta.xml.ws.Holder;
 import org.apache.commons.lang3.exception.ExceptionUtils;
 import org.apache.cxf.jaxrs.client.JAXRSClientFactory;
 import org.apache.cxf.jaxrs.client.WebClient;
@@ -81,7 +93,13 @@ import org.junit.BeforeClass;
 import org.junit.Test;
 
 import static org.hamcrest.CoreMatchers.equalTo;
+import static org.hamcrest.CoreMatchers.is;
+import static org.hamcrest.CoreMatchers.not;
 import static org.hamcrest.MatcherAssert.assertThat;
+import static org.hamcrest.Matchers.greaterThan;
+import static org.hamcrest.Matchers.hasKey;
+import static org.hamcrest.Matchers.lessThan;
+import static org.hamcrest.Matchers.lessThanOrEqualTo;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotNull;
@@ -135,6 +153,114 @@ public class JAXRS20ClientServerBookTest extends AbstractBusClientServerTestBase
         assertEquals(1023L, book.getId());
     }
 
+    @Test
+    public void testGetGenericBookManyClientsInParallel() throws InterruptedException {
+        final ExecutorService pool = Executors.newFixedThreadPool(100);
+        final ThreadMXBean threadMXBean = ManagementFactory.getThreadMXBean();
+        final AtomicLong httpClientThreads = new AtomicLong(); 
+
+        final Supplier<Long> captureHttpClientThreads = () ->
+            Arrays
+                .stream(threadMXBean.getAllThreadIds())
+                .mapToObj(id -> threadMXBean.getThreadInfo(id))
+                .filter(Objects::nonNull)
+                .filter(t -> t.getThreadName().startsWith("HttpClient-"))
+                .filter(t -> t.getThreadName().endsWith("-SelectorManager"))
+                .count();
+
+        // Capture the number of client threads at start
+        final long expectedHttpClientThreads = captureHttpClientThreads.get();
+        final Collection<WebClient> clients = new ArrayList<>();
+        try {
+            final String target = "http://localhost:" + PORT + "/bookstore/genericbooks/123";
+
+            for (int i = 0; i < 1000; ++i) {
+                final WebClient client = WebClient.create(target, true);
+                clients.add(client);
+
+                // We are not checking the future completion, but the fact we were able 
+                // to execute this amount of requests without blowing live threads set 
+                pool.submit(() -> {
+                    Book book = client.sync().get(Book.class);
+                    assertEquals(124L, book.getId());
+
+                    // Capture all "HttpClient-" selector threads
+                    httpClientThreads.accumulateAndGet(captureHttpClientThreads.get(),
+                        (x1, x2) -> x1 > x2 ? x1 : x2);
+                });
+
+                LockSupport.parkNanos(TimeUnit.MILLISECONDS.toNanos(5));
+            }
+        } finally {
+            pool.shutdown();
+            assertThat(pool.awaitTermination(1, TimeUnit.MINUTES), is(true));
+            assertThat(captureHttpClientThreads.get(), greaterThan(0L));
+            assertThat(httpClientThreads.get(), greaterThan(0L));
+            assertThat(httpClientThreads.get(), lessThan(150L)); /* a bit higher that pool size */
+        }
+
+        clients.forEach(WebClient::close);
+    
+        // Since JDK-21, HttpClient Implements AutoCloseable
+        if (Runtime.version().feature() >= 21) { 
+            assertThat(captureHttpClientThreads.get(), lessThanOrEqualTo(expectedHttpClientThreads));
+        }
+    }
+
+    @Test
+    public void testGetGenericBookSingleClientInParallel() throws InterruptedException {
+        final ExecutorService pool = Executors.newFixedThreadPool(100);
+        final String target = "http://localhost:" + PORT + "/bookstore/genericbooks/123";
+        final ThreadMXBean threadMXBean = ManagementFactory.getThreadMXBean();
+
+        final Supplier<Long> captureHttpClientThreads = () ->
+            Arrays
+                .stream(threadMXBean.getAllThreadIds())
+                .mapToObj(id -> threadMXBean.getThreadInfo(id))
+                .filter(Objects::nonNull)
+                .filter(t -> t.getThreadName().startsWith("HttpClient-"))
+                .filter(t -> t.getThreadName().endsWith("-SelectorManager"))
+                .count();
+
+        // Capture the number of client threads at start
+        final long expectedHttpClientThreads = captureHttpClientThreads.get();
+        final WebClient client = WebClient.create(target, true);
+        try {
+            final Collection<Future<?>> futures = new ArrayList<>(); 
+            for (int i = 0; i < 100; ++i) {
+                // We are not checking the future completion, but the fact we were able 
+                // to execute this amount of requests without blowing live threads set 
+                futures.add(
+                    pool.submit(() -> {
+                        Book b1 = client.sync().get(Book.class);
+                        assertEquals(124L, b1.getId());
+                    })
+                );
+            }
+
+            // Find any completed future to make sure conduit was initialized
+            while (true) {
+                if (futures.stream().anyMatch(Future::isDone)) {
+                    break;
+                }
+            }
+        } finally {
+            client.close();
+        }
+
+        pool.shutdown();
+        // Since JDK-21, HttpClient Implements AutoCloseable
+        if (pool.awaitTermination(2, TimeUnit.MINUTES) && Runtime.version().feature() >= 21) {
+            assertThat(captureHttpClientThreads.get(), lessThanOrEqualTo(expectedHttpClientThreads));
+        } else {
+            pool.shutdownNow();
+            // Since JDK-21, HttpClient Implements AutoCloseable
+            if (pool.awaitTermination(2, TimeUnit.MINUTES) && Runtime.version().feature() >= 21) {
+                assertThat(captureHttpClientThreads.get(), lessThanOrEqualTo(expectedHttpClientThreads));
+            }
+        }
+    }
+
     @Test
     public void testGetGenericBook() throws Exception {
         String address = "http://localhost:" + PORT + "/bookstore/genericbooks/123";
@@ -355,6 +481,12 @@ public class JAXRS20ClientServerBookTest extends AbstractBusClientServerTestBase
         String address = "http://localhost:" + PORT + "/wrongpath";
         doTestGetBookAsync(address, false);
     }
+    
+    @Test
+    public void testGetBookAbsolutePathAsync() throws Exception {
+        String address = "http://localhost:" + PORT + "/absolutepath";
+        doTestGetBookAsync(address, false);
+    }
 
     @Test
     public void testPostCollectionGenericEntity() throws Exception {
@@ -472,7 +604,7 @@ public class JAXRS20ClientServerBookTest extends AbstractBusClientServerTestBase
         String endpointAddress =
             "http://localhost:" + PORT + "/bookstore/collections";
         WebClient wc = WebClient.create(endpointAddress,
-                                        Collections.singletonList(new JacksonJaxbJsonProvider()));
+                                        Collections.singletonList(new JacksonXmlBindJsonProvider()));
         doTestPostGetCollectionGenericEntityAndType(wc, MediaType.APPLICATION_JSON_TYPE);
     }
 
@@ -961,8 +1093,36 @@ public class JAXRS20ClientServerBookTest extends AbstractBusClientServerTestBase
         }
     }
 
+    @Test
+    public void testGetHeaders() throws Exception {
+        final WebTarget target = ClientBuilder
+            .newClient()
+            .register(JacksonXmlBindJsonProvider.class)
+            .target("http://localhost:" + PORT + "/bookstore/headers");
 
-    private static class ReplaceBodyFilter implements ClientRequestFilter {
+        @SuppressWarnings("unchecked")
+        final Map<String, Object> headers = target
+            .request().accept("application/json")
+            .get(Map.class);
+
+        assertThat(headers, hasKey("Accept"));
+        assertThat(headers, not(hasKey("Content-Type")));
+    }
+
+    @Test
+    public void testGetBookDateAnnotated() throws Exception {
+        final String response = ClientBuilder
+            .newClient()
+            .target("http://localhost:" + PORT + "/bookstore/annotated/123")
+            .request(MediaType.TEXT_PLAIN)
+            .get()
+            .readEntity(String.class);
+            
+        assertThat(response, equalTo("2020-01-01{jakarta.ws.rs.GET,jakarta.ws.rs.Path,jakarta.ws.rs.Produces,"
+            + "jakarta.ws.rs.ext.Provider,jakarta.ws.rs.Consumes}"));
+    }
+    
+    private static final class ReplaceBodyFilter implements ClientRequestFilter {
 
         @Override
         public void filter(ClientRequestContext rc) throws IOException {
@@ -994,7 +1154,7 @@ public class JAXRS20ClientServerBookTest extends AbstractBusClientServerTestBase
 
     }
 
-    private static class ClientCacheRequestFilter implements ClientRequestFilter {
+    private static final class ClientCacheRequestFilter implements ClientRequestFilter {
 
         @Override
         public void filter(ClientRequestContext context) throws IOException {
@@ -1002,7 +1162,7 @@ public class JAXRS20ClientServerBookTest extends AbstractBusClientServerTestBase
         }
     }
 
-    private static class ClientHeaderRequestFilter implements ClientRequestFilter {
+    private static final class ClientHeaderRequestFilter implements ClientRequestFilter {
 
         @Override
         public void filter(ClientRequestContext context) throws IOException {
@@ -1074,7 +1234,7 @@ public class JAXRS20ClientServerBookTest extends AbstractBusClientServerTestBase
 
     }
 
-    private static class BookInfoInjectableReader implements MessageBodyReader<BookInfo> {
+    private static final class BookInfoInjectableReader implements MessageBodyReader<BookInfo> {
         @Context private ResourceContext resourceContext;
 
         @Override
@@ -1097,7 +1257,7 @@ public class JAXRS20ClientServerBookTest extends AbstractBusClientServerTestBase
 
     }
     
-    private static class BookInfoReader implements MessageBodyReader<BookInfo> {
+    private static final class BookInfoReader implements MessageBodyReader<BookInfo> {
         @Override
         public boolean isReadable(Class<?> arg0, Type arg1, Annotation[] arg2, MediaType arg3) {
             return true;
@@ -1113,7 +1273,7 @@ public class JAXRS20ClientServerBookTest extends AbstractBusClientServerTestBase
 
     }
 
-    private static class ClientTestFeature implements Feature {
+    private static final class ClientTestFeature implements Feature {
 
         @Override
         public boolean configure(FeatureContext context) {
