@@ -29,13 +29,12 @@ import java.util.concurrent.TimeoutException;
 import java.util.concurrent.atomic.AtomicLong;
 import java.util.stream.IntStream;
 
-import javax.ws.rs.ProcessingException;
-import javax.ws.rs.core.MediaType;
-import javax.ws.rs.core.Response;
-import javax.ws.rs.core.Response.Status;
-
-import com.fasterxml.jackson.jaxrs.json.JacksonJsonProvider;
+import com.fasterxml.jackson.jakarta.rs.json.JacksonJsonProvider;
 
+import jakarta.ws.rs.ProcessingException;
+import jakarta.ws.rs.core.MediaType;
+import jakarta.ws.rs.core.Response;
+import jakarta.ws.rs.core.Response.Status;
 import org.apache.cxf.jaxrs.JAXRSServerFactoryBean;
 import org.apache.cxf.jaxrs.client.WebClient;
 import org.apache.cxf.jaxrs.lifecycle.SingletonResourceProvider;
@@ -62,14 +61,7 @@ import io.opentelemetry.context.Context;
 import io.opentelemetry.context.Scope;
 import io.opentelemetry.context.propagation.TextMapSetter;
 import io.opentelemetry.sdk.testing.junit4.OpenTelemetryRule;
-import io.opentelemetry.sdk.trace.data.SpanData;
-import io.opentelemetry.semconv.ClientAttributes;
-import io.opentelemetry.semconv.ErrorAttributes;
 import io.opentelemetry.semconv.HttpAttributes;
-import io.opentelemetry.semconv.NetworkAttributes;
-import io.opentelemetry.semconv.ServerAttributes;
-import io.opentelemetry.semconv.UrlAttributes;
-import io.opentelemetry.semconv.UserAgentAttributes;
 
 import org.junit.After;
 import org.junit.BeforeClass;
@@ -82,12 +74,10 @@ import static org.apache.cxf.systest.jaxrs.tracing.opentelemetry.HasAttribute.ha
 import static org.apache.cxf.systest.jaxrs.tracing.opentelemetry.HasSpan.hasSpan;
 import static org.apache.cxf.systest.jaxrs.tracing.opentelemetry.IsLogContaining.hasItem;
 import static org.awaitility.Awaitility.await;
-import static org.hamcrest.CoreMatchers.containsString;
 import static org.hamcrest.MatcherAssert.assertThat;
 import static org.hamcrest.Matchers.equalTo;
 import static org.hamcrest.Matchers.notNullValue;
 import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertTrue;
 
 public class OpenTelemetryTracingTest extends AbstractClientServerTestBase {
@@ -102,7 +92,7 @@ public class OpenTelemetryTracingTest extends AbstractClientServerTestBase {
     public ExpectedException expectedException = ExpectedException.none();
 
     @BeforeClass
-    public static void startServers() {
+    public static void startServers() throws Exception {
         AbstractResourceInfo.clearAllMaps();
         // keep out of process due to stack traces testing failures
         assertTrue("server did not launch correctly", launchServer(OpenTelemetryServer.class, true));
@@ -133,23 +123,11 @@ public class OpenTelemetryTracingTest extends AbstractClientServerTestBase {
 
         assertThat(otelRule.getSpans().size(), equalTo(2));
         assertThat(otelRule.getSpans().get(0).getName(), equalTo("Get Books"));
-        SpanData serverSpan = otelRule.getSpans().get(1);
-        assertThat(serverSpan.getName(), equalTo("GET /bookstore/books"));
-        assertThat(serverSpan.getAttributes(), hasAttribute(HttpAttributes.HTTP_RESPONSE_STATUS_CODE, 200L));
-        assertThat(serverSpan.getAttributes(), hasAttribute(HttpAttributes.HTTP_REQUEST_METHOD, "GET"));
-        assertThat(serverSpan.getAttributes(), hasAttribute(UrlAttributes.URL_PATH, "/bookstore/books"));
-        assertThat(serverSpan.getAttributes(), hasAttribute(ServerAttributes.SERVER_ADDRESS, "localhost"));
-        assertThat(serverSpan.getAttributes(), hasAttribute(ServerAttributes.SERVER_PORT, Long.valueOf(PORT)));
-        assertThat(serverSpan.getAttributes(), hasAttribute(NetworkAttributes.NETWORK_PEER_ADDRESS, "127.0.0.1"));
-        assertNotNull(serverSpan.getAttributes().get(NetworkAttributes.NETWORK_PEER_PORT));
-        assertThat(serverSpan.getAttributes(), hasAttribute(ClientAttributes.CLIENT_ADDRESS, "127.0.0.1"));
-        assertNotNull(serverSpan.getAttributes().get(ClientAttributes.CLIENT_PORT));
-        assertThat(serverSpan.getAttributes(), hasAttribute(UrlAttributes.URL_SCHEME, "http"));
-        assertThat(serverSpan.getAttributes(), hasAttribute(NetworkAttributes.NETWORK_PROTOCOL_VERSION, "1.1"));
-        String userAgent = serverSpan.getAttributes().get(UserAgentAttributes.USER_AGENT_ORIGINAL);
-        assertNotNull(userAgent);
-        assertThat(userAgent, containsString("Apache-CXF/"));
-        assertThat(serverSpan.getInstrumentationScopeInfo().getName(), equalTo("jaxrs-server-test"));
+        assertThat(otelRule.getSpans().get(1).getName(), equalTo("GET /bookstore/books"));
+        assertThat(otelRule.getSpans().get(1).getAttributes(),
+                   hasAttribute(HttpAttributes.HTTP_RESPONSE_STATUS_CODE, 200L));
+        assertThat(otelRule.getSpans().get(1).getInstrumentationScopeInfo().getName(),
+            equalTo("jaxrs-server-test"));
     }
 
     @Test
@@ -197,7 +175,8 @@ public class OpenTelemetryTracingTest extends AbstractClientServerTestBase {
     @Test
     public void testThatNewChildSpanIsCreatedWhenParentIsProvided() {
         final Response r = createWebClient("/bookstore/books",
-            new OpenTelemetryClientProvider(otelRule.getOpenTelemetry(), "jaxrs-client-test")).get();
+            new OpenTelemetryClientProvider(otelRule.getOpenTelemetry(), "jaxrs-client-test"))
+                .get();
         assertEquals(Status.OK.getStatusCode(), r.getStatus());
 
         assertThat(otelRule.getSpans().toString(), otelRule.getSpans().size(), equalTo(3));
@@ -208,45 +187,6 @@ public class OpenTelemetryTracingTest extends AbstractClientServerTestBase {
         assertThat(otelRule.getSpans().get(2).getInstrumentationScopeInfo().getName(), equalTo("jaxrs-client-test"));
     }
 
-    @Test
-    public void spanShouldHasRequiredAttributes() {
-        final Response r = createWebClient("/bookstore/books",
-                new OpenTelemetryClientProvider(otelRule.getOpenTelemetry(), "jaxrs-client-test"))
-                .get();
-        assertEquals(Status.OK.getStatusCode(), r.getStatus());
-
-        assertThat(otelRule.getSpans().toString(), otelRule.getSpans().size(), equalTo(3));
-
-        SpanData clientSpan = otelRule.getSpans().get(2);
-        assertThat(clientSpan.getName(), equalTo("GET http://localhost:" + PORT + "/bookstore/books"));
-        assertThat(clientSpan.getAttributes(), hasAttribute(HttpAttributes.HTTP_RESPONSE_STATUS_CODE, 200L));
-        assertThat(clientSpan.getAttributes(), hasAttribute(HttpAttributes.HTTP_REQUEST_METHOD, "GET"));
-        assertThat(clientSpan.getAttributes(), hasAttribute(UrlAttributes.URL_FULL,
-                "http://localhost:" + PORT + "/bookstore/books"));
-        assertThat(clientSpan.getAttributes(), hasAttribute(ServerAttributes.SERVER_ADDRESS, "localhost"));
-        assertThat(clientSpan.getAttributes(), hasAttribute(ServerAttributes.SERVER_PORT, Long.valueOf(PORT)));
-        assertThat(clientSpan.getAttributes(), hasAttribute(NetworkAttributes.NETWORK_PEER_ADDRESS, "localhost"));
-        assertThat(clientSpan.getAttributes(), hasAttribute(NetworkAttributes.NETWORK_PEER_PORT, Long.valueOf(PORT)));
-
-        SpanData serverSpan = otelRule.getSpans().get(1);
-        assertThat(serverSpan.getName(), equalTo("GET /bookstore/books"));
-        assertThat(serverSpan.getAttributes(), hasAttribute(HttpAttributes.HTTP_RESPONSE_STATUS_CODE, 200L));
-        assertThat(serverSpan.getAttributes(), hasAttribute(HttpAttributes.HTTP_REQUEST_METHOD, "GET"));
-        assertThat(serverSpan.getAttributes(), hasAttribute(UrlAttributes.URL_PATH, "/bookstore/books"));
-        assertThat(serverSpan.getAttributes(), hasAttribute(ServerAttributes.SERVER_ADDRESS, "localhost"));
-        assertThat(serverSpan.getAttributes(), hasAttribute(ServerAttributes.SERVER_PORT, Long.valueOf(PORT)));
-        assertThat(serverSpan.getAttributes(), hasAttribute(NetworkAttributes.NETWORK_PEER_ADDRESS, "127.0.0.1"));
-        assertNotNull(serverSpan.getAttributes().get(NetworkAttributes.NETWORK_PEER_PORT));
-        assertThat(serverSpan.getAttributes(), hasAttribute(ClientAttributes.CLIENT_ADDRESS, "127.0.0.1"));
-        assertNotNull(serverSpan.getAttributes().get(ClientAttributes.CLIENT_PORT));
-        assertThat(serverSpan.getAttributes(), hasAttribute(UrlAttributes.URL_SCHEME, "http"));
-        assertThat(serverSpan.getAttributes(), hasAttribute(NetworkAttributes.NETWORK_PROTOCOL_VERSION, "1.1"));
-        String userAgent = serverSpan.getAttributes().get(UserAgentAttributes.USER_AGENT_ORIGINAL);
-        assertNotNull(userAgent);
-        assertThat(userAgent, containsString("Apache-CXF/"));
-        assertThat(serverSpan.getInstrumentationScopeInfo().getName(), equalTo("jaxrs-server-test"));
-    }
-
     @Test
     public void testThatNewInnerSpanIsCreatedUsingAsyncInvocation() throws InterruptedException {
         final Context parentContext = fromRandom();
@@ -314,7 +254,7 @@ public class OpenTelemetryTracingTest extends AbstractClientServerTestBase {
         final WebClient client = createWebClient("/bookstore/books",
             new OpenTelemetryClientProvider(otelRule.getOpenTelemetry(), "jaxrs-client-test"));
 
-        // The intention is to make multiple calls one after another, not in parallel, to ensure the
+        // The intention is to make a calls one after another, not in parallel, to ensure the
         // thread have trace contexts cleared out.
         IntStream.range(0, 4).mapToObj(index -> client.async().get()).map(this::get)
             .forEach(r -> assertEquals(Status.OK.getStatusCode(), r.getStatus()));
@@ -324,7 +264,8 @@ public class OpenTelemetryTracingTest extends AbstractClientServerTestBase {
         IntStream.range(0, 4).map(index -> index * 3).forEach(index -> {
             assertThat(otelRule.getSpans().get(index).getName(), equalTo("Get Books"));
             assertThat(otelRule.getSpans().get(index + 1).getName(), equalTo("GET /bookstore/books"));
-            assertThat(otelRule.getSpans().get(index + 2).getName(), equalTo("GET " + client.getCurrentURI()));
+            assertThat(otelRule.getSpans().get(index + 2).getName(),
+                       equalTo("GET " + client.getCurrentURI()));
         });
     }
 
@@ -333,7 +274,7 @@ public class OpenTelemetryTracingTest extends AbstractClientServerTestBase {
         final WebClient client = createWebClient("/bookstore/books",
             new OpenTelemetryClientProvider(otelRule.getOpenTelemetry(), "jaxrs-client-test"));
 
-        // The intention is to make multiple calls one after another, not in parallel, to ensure the
+        // The intention is to make a calls one after another, not in parallel, to ensure the
         // thread have trace contexts cleared out.
         IntStream.range(0, 4).mapToObj(index -> client.get())
             .forEach(r -> assertEquals(Status.OK.getStatusCode(), r.getStatus()));
@@ -343,7 +284,8 @@ public class OpenTelemetryTracingTest extends AbstractClientServerTestBase {
         IntStream.range(0, 4).map(index -> index * 3).forEach(index -> {
             assertThat(otelRule.getSpans().get(index).getName(), equalTo("Get Books"));
             assertThat(otelRule.getSpans().get(index + 1).getName(), equalTo("GET /bookstore/books"));
-            assertThat(otelRule.getSpans().get(index + 2).getName(), equalTo("GET " + client.getCurrentURI()));
+            assertThat(otelRule.getSpans().get(index + 2).getName(),
+                       equalTo("GET " + client.getCurrentURI()));
         });
     }
 
@@ -453,37 +395,9 @@ public class OpenTelemetryTracingTest extends AbstractClientServerTestBase {
         assertEquals(Status.INTERNAL_SERVER_ERROR.getStatusCode(), r.getStatus());
 
         assertThat(otelRule.getSpans().toString(), otelRule.getSpans().size(), equalTo(1));
-        SpanData serverSpan = otelRule.getSpans().get(0);
-
-        assertThat(serverSpan.getName(), equalTo("GET /bookstore/books/exception"));
-        assertThat(serverSpan.getAttributes(), hasAttribute(HttpAttributes.HTTP_RESPONSE_STATUS_CODE, 500L));
-        assertThat(serverSpan.getAttributes(), hasAttribute(HttpAttributes.HTTP_REQUEST_METHOD, "GET"));
-        assertThat(serverSpan.getAttributes(), hasAttribute(UrlAttributes.URL_PATH, "/bookstore/books/exception"));
-        assertThat(serverSpan.getAttributes(), hasAttribute(ServerAttributes.SERVER_ADDRESS, "localhost"));
-        assertThat(serverSpan.getAttributes(), hasAttribute(ServerAttributes.SERVER_PORT, Long.valueOf(PORT)));
-        assertThat(serverSpan.getAttributes(), hasAttribute(ErrorAttributes.ERROR_TYPE,  String.valueOf(500)));
-    }
-
-    @Test
-    public void testClientSpanAttributesOnException() {
-        final Response r = createWebClient("/bookstore/books/exception",
-                new OpenTelemetryClientProvider(otelRule.getOpenTelemetry(), "jaxrs-client-test"))
-                .get();
-
-        assertEquals(Status.INTERNAL_SERVER_ERROR.getStatusCode(), r.getStatus());
-
-        assertThat(otelRule.getSpans().toString(), otelRule.getSpans().size(), equalTo(2));
-
-        SpanData clientSpan = otelRule.getSpans().get(1);
-        assertThat(clientSpan.getName(), equalTo("GET http://localhost:" + PORT + "/bookstore/books/exception"));
-        assertThat(clientSpan.getAttributes(), hasAttribute(HttpAttributes.HTTP_REQUEST_METHOD, "GET"));
-        assertThat(clientSpan.getAttributes(), hasAttribute(UrlAttributes.URL_FULL,
-                "http://localhost:" + PORT + "/bookstore/books/exception"));
-        assertThat(clientSpan.getAttributes(), hasAttribute(ServerAttributes.SERVER_ADDRESS, "localhost"));
-        assertThat(clientSpan.getAttributes(), hasAttribute(ServerAttributes.SERVER_PORT, Long.valueOf(PORT)));
-        assertThat(clientSpan.getAttributes(), hasAttribute(NetworkAttributes.NETWORK_PEER_ADDRESS, "localhost"));
-        assertThat(clientSpan.getAttributes(), hasAttribute(NetworkAttributes.NETWORK_PEER_PORT, Long.valueOf(PORT)));
-        assertThat(clientSpan.getAttributes(), hasAttribute(ErrorAttributes.ERROR_TYPE,  String.valueOf(500)));
+        assertThat(otelRule.getSpans().get(0).getName(), equalTo("GET /bookstore/books/exception"));
+        assertThat(otelRule.getSpans().get(0).getAttributes(),
+                   hasAttribute(HttpAttributes.HTTP_RESPONSE_STATUS_CODE, 500L));
     }
 
     @Test
